pub(crate) fn one_or_more<P>(
parser: P,
) -> impl for<'a> Fn(&'a [u8]) -> Option<ParsedItem<'a, ()>>Expand description
Consume one of or more instances of the provided parser. The parser must produce the unit value.
pub(crate) fn one_or_more<P>(
parser: P,
) -> impl for<'a> Fn(&'a [u8]) -> Option<ParsedItem<'a, ()>>Consume one of or more instances of the provided parser. The parser must produce the unit value.