pub(crate) fn one_or_two_digits(input: &[u8]) -> Option<ParsedItem<'_, u8>>Expand description
Consume one or two digits, returning the numerical value.
pub(crate) fn one_or_two_digits(input: &[u8]) -> Option<ParsedItem<'_, u8>>Consume one or two digits, returning the numerical value.